<?php
/* Mega Menu widget class */
if ( ! class_exists( 'dc_jqmegamenu_widget' ) ) {
	class dc_jqmegamenu_widget extends WP_Widget {
		/** constructor */
		public function __construct() {

			$name = __( 'jQuery Mega Menu','megamenu' );
			$desc = __( 'Use this widget to create any WordPress menu into a multi-column mega menu. To learn more about the required menu structure','megamenu' );
			$id_base = 'dc_jqmegamenu_widget';
			$css_class = '';
			$alt_option = 'widget_dcjq_mega_menu_navigation';
			$widget_ops = array(
				'classname' => $css_class,
				'description' => sprintf( __( '%s','megamenu' ), $desc ),
			);
			parent::__construct( 'nav_menu', __( 'Custom Menu','megamenu' ), $widget_ops );

			parent::__construct( $id_base,  sprintf( __( '%s','megamenu' ), $name ), $widget_ops );
			$this->alt_option_name = $alt_option;
			/* add_action( 'wp_head', array(&$this, 'styles'), 10, 1 );	*/
			add_action( 'wp_footer', array( &$this, 'footer' ), 11, 1 );
			$this->defaults = array(
				'title' => '',
				'rowItems' => 3,
				'subMenuWidth' => '150px',
				'speed' => 'slow',
				'effect' => 'fade',
				'event' => 'hover',
			);
		}
		function widget( $args, $instance ) {
			extract( $args );
			/* Get menu */
			$widget_options = wp_parse_args( $instance, $this->defaults );
			extract( $widget_options, EXTR_SKIP );
			$nav_menu = wp_get_nav_menu_object( $instance['nav_menu'] );
			if ( ! $nav_menu ) {
				return;
			}

			/* echo $args['before_widget']; */
			?>
			<div class="mega-menu nav-secondary columns" id="<?php echo $this->id . '-item'; ?>">
				<div id="menu_secondary_mega_menu" class="mega_menu_wrap ">
					<div id="menu-secondary-title" class="currentmenu3 currentmenu2">
						<?php _e( 'Menu', 'megamenu' ); ?>
					</div>					
					<div class="nav_bg">
						<?php
							wp_nav_menu( array(
								'menu' => $nav_menu,
								'container' => false,
								'menu_class' => 'mega',
							) );
							do_action( 'show_secondary_navigation_right' );
						?>
						<div class="clearfix"></div>
					</div>
				</div>
			</div>
			<?php
			/* echo $args['after_widget']; */
		}
		/** @see WP_Widget::update */
		function update( $new_instance, $old_instance ) {
			$instance['nav_menu'] = (int) $new_instance['nav_menu'];
			$instance['rowItems'] = $new_instance['rowItems'];
			$instance['subMenuWidth'] = $new_instance['subMenuWidth'];
			$instance['speed'] = $new_instance['speed'];
			$instance['effect'] = $new_instance['effect'];
			$instance['event'] = $new_instance['event'];
			$instance['fullWidth'] = $new_instance['fullWidth'];
			return $instance;
		}
		/** @see WP_Widget::form */
		function form( $instance ) {
			$nav_menu = isset( $instance['nav_menu'] ) ? $instance['nav_menu'] : '';
			$rowItems = isset( $instance['rowItems'] ) ? $instance['rowItems'] : '';
			$subMenuWidth = isset( $instance['subMenuWidth'] ) ? $instance['subMenuWidth'] : '';
			$speed = isset( $instance['speed'] ) ? $instance['speed'] : '';
			$effect = isset( $instance['effect'] ) ? $instance['effect'] : '';
			$event = isset( $instance['event'] ) ? $instance['event'] : '';
			$fullWidth = isset( $instance['fullWidth'] ) ? $instance['fullWidth'] : '';
			$widget_options = wp_parse_args( $instance, $this->defaults );
			extract( $widget_options, EXTR_SKIP );
			/* Get menus */
			if ( get_option( 'ptthemes_show_empty_category' ) == 'No' ) {
						$hide_empty = 'false';
			} else {
				$hide_empty = 'true';
			}
			$menus = get_terms( 'nav_menu', array(
				'hide_empty' => $hide_empty,
			) );
			/* If no menus exists, direct the user to go and create some. */
			if ( ! $menus ) {
				echo '<p>' . sprintf( __( 'No menus have been created yet. <a href="%s">Create some</a>.' ), admin_url( 'nav-menus.php' ) ) . '</p>';
				return;
			}
			?>
		<p>
			<label for="<?php echo $this->get_field_id( 'nav_menu' ); ?>"><?php _e( 'Select Menu:','megamenu' ); ?></label>
			<select id="<?php echo $this->get_field_id( 'nav_menu' ); ?>" name="<?php echo $this->get_field_name( 'nav_menu' ); ?>">
			<?php
			foreach ( $menus as $menu ) {
				$selected = $nav_menu == $menu->term_id ? ' selected="selected"' : '';
				echo '<option' . $selected . ' value="' . $menu->term_id . '">' . $menu->name . '</option>';
			}
			?>
			</select>
		</p>
		<p>
			<input type="radio" id="<?php echo $this->get_field_id( 'event1' ); ?>" name="<?php echo $this->get_field_name( 'event' ); ?>" value="click"<?php checked( $event, 'click' ); ?> /> 
			<label for="<?php echo $this->get_field_id( 'event1' ); ?>"><?php _e( 'Click' , 'megamenu' ); ?></label>
			<input type="radio" id="<?php echo $this->get_field_id( 'event2' ); ?>" name="<?php echo $this->get_field_name( 'event' ); ?>" value="hover"<?php checked( $event, 'hover' ); ?> /> 
			<label for="<?php echo $this->get_field_id( 'event2' ); ?>"><?php _e( 'Hover' , 'megamenu' ); ?></label>
		</p>
		<p>
		  <label for="<?php echo $this->get_field_id( 'rowItems' ); ?>"><?php _e( 'Number of Items Per Row' , 'megamenu' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'rowItems' ); ?>" id="<?php echo $this->get_field_id( 'rowItems' ); ?>" >
				<option value='1' <?php selected( $rowItems, '1' ); ?> >1</option>
				<option value='2' <?php selected( $rowItems, '2' ); ?> >2</option>
				<option value='3' <?php selected( $rowItems, '3' ); ?> >3</option>
				<option value='4' <?php selected( $rowItems, '4' ); ?> >4</option>
			</select>
			</p>
			
		</p>
		<input type="hidden" value="<?php echo $subMenuWidth; ?>" class="widefat" id="<?php echo $this->get_field_id( 'subMenuWidth' ); ?>" name="<?php echo $this->get_field_name( 'subMenuWidth' ); ?>" />
		<p><label for="<?php echo $this->get_field_id( 'effect' ); ?>"><?php _e( 'Animation Effect:', 'megamenu' ); ?>
			<select name="<?php echo $this->get_field_name( 'effect' ); ?>" id="<?php echo $this->get_field_id( 'effect' ); ?>" >
				<option value='fade' <?php selected( $effect, 'fade' ); ?> ><?php _e( 'Fade In','megamenu' );?></option>
				<option value='slide' <?php selected( $effect, 'slide' ); ?> ><?php _e( 'Slide Down','megamenu' );?></option>
			</select>
			</label>
		</p>
		<p><label for="<?php echo $this->get_field_id( 'speed' ); ?>"><?php _e( 'Animation Speed:', 'megamenu' ); ?>
			<select name="<?php echo $this->get_field_name( 'speed' ); ?>" id="<?php echo $this->get_field_id( 'speed' ); ?>" >
				<option value='0' <?php selected( $speed, '0' ); ?> ><?php _e( 'No Animation','megamenu' );?></option>
				<option value='fast' <?php selected( $speed, 'fast' ); ?> ><?php _e( 'Fast','megamenu' );?></option>
				<option value='normal' <?php selected( $speed, 'normal' ); ?> ><?php _e( 'Normal','megamenu' );?></option>
				<option value='slow' <?php selected( $speed, 'slow' ); ?> ><?php _e( 'Slow','megamenu' );?></option>
			</select>
			</label>
		</p>
			<?php do_action( 'megamenu_fullwidget',$this,$instance );

		}
		/** Adds ID based activation script to the footer */
		function footer() {
			if ( ! is_admin() ) {
				$all_widgets = $this->get_settings();
				foreach ( $all_widgets as $key => $wpdcjqmegamenu ) {
					$widget_id = $this->id_base . '-' . $key;
					if ( is_active_widget( false, $widget_id, $this->id_base ) ) {
						$effect = $wpdcjqmegamenu['effect'];
						if ( $effect == '' ) {$effect = 'fade';}
						$event = $wpdcjqmegamenu['event'];
						if ( $event == '' ) {$event = 'hover';}
						$fullWidth = $wpdcjqmegamenu['fullWidth'];
						if ( $fullWidth != '' ) {$fullWidth = ',fullWidth: true';}
					?>
					<script type="text/javascript">
					var $mgc = jQuery.noConflict();
						$mgc(document).ready(function() {
							$mgc('#<?php echo $widget_id . '-item'; ?> .mega').dcMegaMenu({
								rowItems: <?php echo ($wpdcjqmegamenu['rowItems']) ? $wpdcjqmegamenu['rowItems'] : 1; ?>,
								subMenuWidth: '<?php echo $wpdcjqmegamenu['subMenuWidth']; ?>',
								speed: <?php echo $wpdcjqmegamenu['speed'] == '0' ? 0 : "'" . $wpdcjqmegamenu['speed'] . "'"; ?>,
								effect: '<?php echo $effect; ?>',
								event: '<?php echo $event; ?>'
								<?php echo $fullWidth; ?>
							});
						});
						
				</script>
				
					<?php

					}
				}
			}
		}
	} /* class dc_jqmegamenu_widget  */
}// End if().
?>
